How to cite SAlib
-----------------

If you would like to use our software, please cite it using the following:

    Herman, J. and Usher, W. (2017) SALib: An open-source Python library for
    sensitivity analysis. Journal of Open Source Software, 2(9).
    doi:10.21105/joss.00097

|paper status|

If you use BibTeX, cite using the following entry::

    @article{Herman2017,
        doi = {10.21105/joss.00097},
        url = {https://doi.org/10.21105/joss.00097},
        year  = {2017},
        month = {jan},
        publisher = {The Open Journal},
        volume = {2},
        number = {9},
        author = {Jon Herman and Will Usher},
        title = {{SALib}: An open-source Python library for Sensitivity Analysis},
        journal = {The Journal of Open Source Software}
    }


Projects that use SALib
-----------------------

Many projects now use the Global Sensitivity Analysis features provided by
SALib. Here is a selection:


Software
~~~~~~~~

* `The City Energy Analyst <https://github.com/architecture-building-systems/CEAforArcGIS>`_
* `pynoddy <https://github.com/flohorovicic/pynoddy>`_
* `savvy <https://github.com/houghb/savvy>`_
* `rhodium <https://github.com/Project-Platypus/Rhodium>`_
* `pySur <https://github.com/MastenSpace/pysur>`_
* `EMA workbench <https://github.com/quaquel/EMAworkbench>`_
* `Brain/Circulation Model Developer <https://github.com/bcmd/BCMD>`_
* `DAE Tools <http://daetools.com/>`_
* `agentpy <https://github.com/JoelForamitti/agentpy>`_
* `uncertainpy <https://github.com/simetenn/uncertainpy>`_


Blogs
~~~~~

* `Sensitivity Analyis in Python <http://www.perrygeo.com/sensitivity-analysis-in-python.html>`_
* `Sensitivity Analysis with SALib <http://keyboardscientist.weebly.com/blog/sensitivity-analysis-with-salib>`_
* `Running Sobol using SALib <https://waterprogramming.wordpress.com/2013/08/05/running-sobol-sensitivity-analysis-using-salib/>`_
* `Extensions of SALib for more complex sensitivity analyses <https://waterprogramming.wordpress.com/2014/02/11/extensions-of-salib-for-more-complex-sensitivity-analyses/>`_


Videos
~~~~~~

* `PyData Presentation on SALib <https://youtu.be/gkR_lz5OptU>`_

If you would like to be added to this list, please submit a pull request,
or create an issue.

Many thanks for using SALib.